@@ -10,7 +10,6 @@ Compatible with both Python 2 and Python 3.
 
 from __future__ import print_function, unicode_literals
 
-
 try:
     # noinspection PyUnresolvedReferences
     string_input = raw_input
@@ -23,8 +22,8 @@ def color(text):
     Replaces text in brackets with yellow bold variant for terminal. Also replaces | symbol with
     blue one. Should improve readability. Uses ANSI Styling codes.
     """
-    colored = text.replace('(', '\033[33m\033[1m').replace(')', '\033[0m')
-    colored = colored.replace('|', '\033[94m\033[1m|\033[0m')
+    colored = text.replace("(", "\033[33m\033[1m").replace(")", "\033[0m")
+    colored = colored.replace("|", "\033[94m\033[1m|\033[0m")
     return colored
 
 
@@ -43,13 +42,21 @@ def ask_interactively(version=3.1, all_metrics=False, no_colors=False):
     """
     # Import correct constants
     if version == 2:
-        print('Interactive CVSS2 calculator')
-        from .constants2 import METRICS_ABBREVIATIONS, METRICS_MANDATORY, METRICS_VALUE_NAMES
+        print("Interactive CVSS2 calculator")
+        from .constants2 import (
+            METRICS_ABBREVIATIONS,
+            METRICS_MANDATORY,
+            METRICS_VALUE_NAMES,
+        )
     elif version >= 3.0:
-        print('Interactive CVSS3 calculator')
-        from .constants3 import METRICS_ABBREVIATIONS, METRICS_MANDATORY, METRICS_VALUE_NAMES
+        print("Interactive CVSS3 calculator")
+        from .constants3 import (
+            METRICS_ABBREVIATIONS,
+            METRICS_MANDATORY,
+            METRICS_VALUE_NAMES,
+        )
     else:
-        raise ValueError('Unknown version: {0}'.format(version))
+        raise ValueError("Unknown version: {0}".format(version))
     print()
 
     vector = []
@@ -61,7 +68,7 @@ def ask_interactively(version=3.1, all_metrics=False, no_colors=False):
 
     for metric in metrics:
         # Print full metric name
-        print(METRICS_ABBREVIATIONS[metric] + ':', end=' ')
+        print(METRICS_ABBREVIATIONS[metric] + ":", end=" ")
 
         # Create metric value names with hints
         values = METRICS_VALUE_NAMES[metric]
@@ -70,22 +77,22 @@ def ask_interactively(version=3.1, all_metrics=False, no_colors=False):
             name = METRICS_VALUE_NAMES[metric][value]
             name_with_hints = name
             for letter in value:
-                name_with_hints = name_with_hints.replace(letter, '(' + letter + ')')
+                name_with_hints = name_with_hints.replace(letter, "(" + letter + ")")
 
             # Exceptions for hints
-            if version >= 3.0 and name_with_hints == 'Not Defined':
-                name_with_hints = '(X)Not Defined'
+            if version >= 3.0 and name_with_hints == "Not Defined":
+                name_with_hints = "(X)Not Defined"
             elif version < 3.0:
                 name_with_hints = {
-                    '(P)roof-of-(C)oncept': '(P)roof-(O)f-(C)oncept',
-                    '(U)nconfirmed': '(U)n(C)onfirmed',
-                    '(U)ncorroborated': '(U)nco(R)roborated',
+                    "(P)roof-of-(C)oncept": "(P)roof-(O)f-(C)oncept",
+                    "(U)nconfirmed": "(U)n(C)onfirmed",
+                    "(U)ncorroborated": "(U)nco(R)roborated",
                 }.get(name_with_hints, name_with_hints)
 
             value_names.append(name_with_hints)
 
         # Print value names with hints
-        value_names_string = ' | '.join(value_names)
+        value_names_string = " | ".join(value_names)
         if no_colors:
             print(value_names_string)
         else:
@@ -93,23 +100,23 @@ def ask_interactively(version=3.1, all_metrics=False, no_colors=False):
 
         # Ask for input
         while True:
-            print(METRICS_ABBREVIATIONS[metric] + ':', end=' ')
-            print('/'.join(values), end=' ')
+            print(METRICS_ABBREVIATIONS[metric] + ":", end=" ")
+            print("/".join(values), end=" ")
             input_value = string_input().upper()
             if not input_value:
                 if version == 2:
-                    input_value = 'ND'
+                    input_value = "ND"
                 else:
-                    input_value = 'X'
+                    input_value = "X"
             if input_value in values:
-                vector.append(metric + ':' + input_value)
+                vector.append(metric + ":" + input_value)
                 break
         print()
 
     if version == 3.0:
-        vector_string = 'CVSS:3.0/' + '/'.join(vector)
+        vector_string = "CVSS:3.0/" + "/".join(vector)
     elif version == 3.1:
-        vector_string = 'CVSS:3.1/' + '/'.join(vector)
+        vector_string = "CVSS:3.1/" + "/".join(vector)
     else:
-        vector_string = '/'.join(vector)
+        vector_string = "/".join(vector)
     return vector_string
